## `keyword_lookup`


The purpose of the [`keyword_lookup`](../_api/soxspipe.commonutils.keyword_lookup.html) utility is to act as a lookup-reference in the code for specific SOXS FITS Header keywords.

When initiated [`keyword_lookup`](../_api/soxspipe.commonutils.keyword_lookup.html) reads the keywords from a [Keyword Dictionary](../files/keyword_dictionary.md) file and can later serve the keywords names to the soxspipe code when requested.

```eval_rst
.. autoclass:: soxspipe.commonutils.keyword_lookup
    :members:
```
